import React from 'react';
import { scaleTime, extent, scaleLog, max, line } from 'd3';
import { XAxis } from './XAxis';
import { YAxis } from './YAxis';

const xValue = (d) => d.date;
const yValue = (d) => d.deathTotal;

const margin = { top: 40, left: 80, bottom: 50, right: 80 };

export const LineChart = ({ data, height, width }) => {
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;

  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth]);

  const yScale = scaleLog()
    .domain([1, max(data, yValue)])
    .range([innerHeight, 0])
    .nice();

  const lineGenerator = line()
    .x((d) => xScale(xValue(d)))
    .y((d) => yScale(yValue(d)));

  const mostRecentDate = xScale.domain()[1];

  return (
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left}, ${margin.top})`}
      >
        <XAxis xScale={xScale} innerHeight={innerHeight} />
        <YAxis yScale={yScale} innerWidth={innerWidth} />
        <path d={lineGenerator(data)} />
        <text
          transform={`translate(${innerWidth / 2}, -10)`}
          text-anchor="middle"
        >
          Global Coronavirus Deaths Over Time
        </text>
        <text
          className="axis-label"
          transform={`translate(-40, ${innerHeight / 2}) rotate(-90)`}
          text-anchor="middle"
         
        >
          Cumulative Death
        </text>
        <text
          className="axis-label"
          transform={`translate(${innerWidth / 2}, ${innerHeight +25})`}
          text-anchor="middle"
          alignment-baseline="hanging"
        >
          Time
        </text>
      </g>
    </svg>
  );
};
